@@ -24,6 +24,9 @@
  *   IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#ifndef __D2U_COMMON_H
+#define __D2U_COMMON_H
+
 /* define feature test macros for realpath() -- needed on    */
 /* systems that have S_ISLNK, but chicken/egg means we must  */
 /* define early, before including stdlib.h (or sys/stat.h)   */
@@ -161,7 +164,7 @@
 #define OUTPUTFILE_SYMLINK 0x8
 #define INPUT_TARGET_NO_REGFILE 0x10
 #define OUTPUT_TARGET_NO_REGFILE 0x20
-#define LOCALE_NOT_UTF8 0x40
+#define LOCALE_NOT_UTF 0x40     /* Locale not an Unicode Transformation Format */
 #define WCHAR_T_TOO_SMALL 0x80
 #define UNICODE_CONVERSION_ERROR 0x100
 
@@ -178,8 +181,16 @@
 
 #define FROMTO_DOS2UNIX 0
 #define FROMTO_MAC2UNIX 1
-#define FROMTO_UNIX2DOS 0
-#define FROMTO_UNIX2MAC 1
+#define FROMTO_UNIX2DOS 2
+#define FROMTO_UNIX2MAC 3
+
+#define INFO_DOS  0x1
+#define INFO_UNIX 0x2
+#define INFO_MAC  0x4
+#define INFO_BOM  0x8
+#define INFO_TEXT 0x10
+#define INFO_DEFAULT 0x1F
+#define INFO_CONVERT 0x20
 
 #define SYMLINK_SKIP 0
 #define SYMLINK_FOLLOW 1
@@ -189,11 +200,16 @@
 #define FILE_UTF16LE 1  /* UTF-16 Little Endian */
 #define FILE_UTF16BE 2  /* UTF-16 Big Endian */
 #define FILE_UTF8    3  /* UTF-8 */
+#define FILE_GB18030 4  /* GB18030 */
+
+/* locale conversion targets */
+#define TARGET_UTF8    0
+#define TARGET_GB18030 1
 
 typedef struct
 {
   int NewFile;                          /* is in new file mode? */
-  int Quiet;                            /* is in quiet mode? */
+  int verbose;                          /* 0 = quiet, 1 = normal, 2 = verbose */
   int KeepDate;                         /* should keep date stamp? */
   int ConvMode;                         /* 0: ascii, 1: 7bit, 2: iso */
   int FromToMode;                       /* 0: dos2unix/unix2dos, 1: mac2unix/unix2mac */
@@ -206,17 +222,20 @@ typedef struct
   int bomtype;                          /* byte order mark */
   int add_bom;                          /* 1: write BOM */
   int keep_bom;                         /* 1: write BOM if input file has BOM. 0: Do not write BOM */
+  int keep_utf16;                       /* 1: write UTF-16 format when input file is UTF-16 format */
+  int file_info;                        /* 1: print file information */
+  int locale_target;                    /* locale conversion target. 0: UTF-8; 1: GB18030 */
 } CFlag;
 
 
 int symbolic_link(const char *path);
-int regfile(char *path, int allowSymlinks, CFlag *ipFlag, char *progname);
-int regfile_target(char *path, CFlag *ipFlag, char *progname);
-void PrintUsage(char *progname);
+int regfile(char *path, int allowSymlinks, CFlag *ipFlag, const char *progname);
+int regfile_target(char *path, CFlag *ipFlag, const char *progname);
+void PrintUsage(const char *progname);
 void PrintBSDLicense(void);
-void PrintVersion(char *progname);
+void PrintVersion(const char *progname, const char *localedir);
 #ifdef ENABLE_NLS
-void PrintLocaledir(char *localedir);
+void PrintLocaledir(const char *localedir);
 #endif
 FILE* OpenInFile(char *ipFN);
 FILE* OpenOutFile(int fd);
@@ -228,11 +247,37 @@ FILE* MakeTempFileFrom(const char *OutFN, char **fname_ret);
 #else
 int MakeTempFileFrom(const char *OutFN, char **fname_ret);
 #endif
-int ResolveSymbolicLink(char *lFN, char **rFN, CFlag *ipFlag, char *progname);
+int ResolveSymbolicLink(char *lFN, char **rFN, CFlag *ipFlag, const char *progname);
 FILE *read_bom (FILE *f, int *bomtype);
+FILE *write_bom (FILE *f, CFlag *ipFlag, const char *progname);
+void print_bom (const int bomtype, const char *filename, const char *progname);
+int check_unicode(FILE *InF, FILE *TempF,  CFlag *ipFlag, const char *ipInFN, const char *progname);
+void print_messages_stdio(const CFlag *pFlag, const char *progname);
+void print_messages_newfile(const CFlag *pFlag, const char *infile, const char *outfile, const char *progname, const int RetVal);
+void print_messages_oldfile(const CFlag *pFlag, const char *infile, const char *progname, const int RetVal);
+int ConvertNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, const char *progname,
+                   int (*Convert)(FILE*, FILE*, CFlag *, const char *)
+#ifdef D2U_UNICODE
+                 , int (*ConvertW)(FILE*, FILE*, CFlag *, const char *)
+#endif
+                  );
+int ConvertStdio(CFlag *ipFlag, const char *progname,
+                   int (*Convert)(FILE*, FILE*, CFlag *, const char *)
+#ifdef D2U_UNICODE
+                 , int (*ConvertW)(FILE*, FILE*, CFlag *, const char *)
+#endif
+                  );
+int parse_options(int argc, char *argv[], CFlag *pFlag, const char *localedir, const char *progname,
+                  void (*PrintLicense)(void),
+                  int (*Convert)(FILE*, FILE*, CFlag *, const char *)
+#ifdef D2U_UNICODE
+                , int (*ConvertW)(FILE*, FILE*, CFlag *, const char *)
+#endif
+                  );
 #ifdef D2U_UNICODE
 wint_t d2u_getwc(FILE *f, int bomtype);
 wint_t d2u_ungetwc(wint_t wc, FILE *f, int bomtype);
 wint_t d2u_putwc(wint_t wc, FILE *f, CFlag *ipFlag);
 #endif
 
+#endif
