@@ -8,7 +8,7 @@
  *  See also http://www.freebsd.org/copyright/freebsd-license.html
  *  --------
  *
- *  Copyright (C) 2009-2014 Erwin Waterlander
+ *  Copyright (C) 2009-2015 Erwin Waterlander
  *  Copyright (C) 1994-1995 Benjamin Lin.
  *  All rights reserved.
  *
@@ -64,7 +64,7 @@
 void PrintLicense(void)
 {
   printf("%s", _("\
-Copyright (C) 2009-2014 Erwin Waterlander\n\
+Copyright (C) 2009-2015 Erwin Waterlander\n\
 Copyright (C) 1994-1995 Benjamin Lin\n\
 All rights reserved.\n\n"));
   PrintBSDLicense();
@@ -130,7 +130,7 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
               fprintf(stderr, "%s: ", progname);
-              fprintf(stderr, _("Binary symbol 0x00%02X found at line %d\n"),TempChar, line_nr);
+              fprintf(stderr, _("Binary symbol 0x00%02X found at line %u\n"), TempChar, line_nr);
             }
             break;
           }
@@ -180,7 +180,7 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
               fprintf(stderr, "%s: ", progname);
-              fprintf(stderr, _("Binary symbol 0x00%02X found at line %d\n"),TempChar, line_nr);
+              fprintf(stderr, _("Binary symbol 0x00%02X found at line %u\n"), TempChar, line_nr);
             }
             break;
           }
@@ -251,7 +251,7 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
     }
     if (ipFlag->verbose > 1) {
       fprintf(stderr, "%s: ", progname);
-      fprintf(stderr, _("Converted %d out of %d line breaks.\n"),converted, line_nr -1);
+      fprintf(stderr, _("Converted %u out of %u line breaks.\n"), converted, line_nr -1);
     }
     return RetVal;
 }
@@ -275,8 +275,8 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
 
     switch (ipFlag->ConvMode) {
       case CONVMODE_ASCII: /* ascii */
-      case CONVMODE_UTF16LE: /* Assume UTF-16LE, bomtype = FILE_UTF8 */
-      case CONVMODE_UTF16BE: /* Assume UTF-16BE, bomtype = FILE_UTF8 */
+      case CONVMODE_UTF16LE: /* Assume UTF-16LE, bomtype = FILE_UTF8 or GB18030 */
+      case CONVMODE_UTF16BE: /* Assume UTF-16BE, bomtype = FILE_UTF8 or GB18030 */
         ConvTable = U2DAsciiTable;
         break;
       case CONVMODE_7BIT: /* 7bit */
@@ -332,7 +332,7 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
               fprintf(stderr, "%s: ", progname);
-              fprintf(stderr, _("Binary symbol 0x%02X found at line %d\n"),TempChar, line_nr);
+              fprintf(stderr, _("Binary symbol 0x%02X found at line %u\n"), TempChar, line_nr);
             }
             break;
           }
@@ -380,7 +380,7 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
               fprintf(stderr, "%s: ", progname);
-              fprintf(stderr, _("Binary symbol 0x%02X found at line %d\n"),TempChar, line_nr);
+              fprintf(stderr, _("Binary symbol 0x%02X found at line %u\n"), TempChar, line_nr);
             }
             break;
           }
@@ -445,7 +445,7 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
     }
     if (ipFlag->verbose > 1) {
       fprintf(stderr, "%s: ", progname);
-      fprintf(stderr, _("Converted %d out of %d line breaks.\n"),converted, line_nr -1);
+      fprintf(stderr, _("Converted %u out of %u line breaks.\n"), converted, line_nr -1);
     }
     return RetVal;
 }
